# ==================================================================
# Plugins::GForum::Block_PM - Auto Generated Program Module
#
#   Plugins::GForum::Block_PM
#   Author  : Paul Wilson
#   Version : 1.0.0
#   Updated : Sat Aug 31 20:17:36 2002
#
# ==================================================================
#

package Plugins::GForum::Block_PM;
# ==================================================================

   use strict;
   use GT::Base;
   use GForum::Template;
   use GT::Plugins qw/STOP CONTINUE/;
   use GForum qw/$USER $IN $DB $CFG/;

# Inherit from base class for debug and error methods
   @Plugins::GForum::Block_PM::ISA = qw(GT::Base);

# PLUGIN HOOKS
# ===================================================================

sub check_block {
# -------------------------------------------------------------------
# Run this hook whenever do_message_send runs.

    my $do = shift;
    my $us;

# Ugh the preview/reply pages use an id instead of a username.
   $us = $IN->param('user') ?
         $DB->table('User')->select( { user_id => scalar $IN->param('user') }, 'user_username' )->fetchrow :
         $IN->param('user_username');
        
        
# If user_username is blank or the user accepts no pms there is no point going any further.
    return $do unless ($us && $USER->{user_accept_privmsg});

# Now check whether this user is blocked from sending to user_username
    if (my $recip_id = $DB->table('User')->select( { user_username => $us }, 'user_id' )->fetchrow) {
        if ($DB->table('Block_PM')->count( { blocker_user_id_fk => $recip_id, blocked_user_id_fk => $USER->{user_id} } )) {
            GT::Plugins->action( STOP );
            $GForum::Template::VARS{error} = GForum::language('BLOCK_PM', $us);
            return GForum::do_func('bad_action');
        }
    }
        
    return $do;
}

sub load_blocks {
# -------------------------------------------------------------------
# Load blocks when the do_user_profile_basic hook runs.

    my (@args)  = @_;
    my (@users) = ();

# Load existing blocks.
    my @ids = $DB->table('Block_PM')->select( { blocker_user_id_fk => $USER->{user_id} }, 'blocked_user_id_fk' )->fetchall_list;
    foreach my $id (@ids) {
        my $user = $DB->table('User')->select( { user_id => $id }, 'user_username' )->fetchrow;
        push (@users, $user) if $user;
    }

# Set the new tag.
    $GForum::Template::VARS{block_pm} = join "\n", @users;

    return @args;
}

sub save_blocks {
# -------------------------------------------------------------------
# Save blocks when the do_profile_basic hook runs.

    my (@args) = @_;
    my ($list) = $IN->param('block_pm');
    my (@errs) = ();

# Delete all records for this user to start with.
    $DB->table('Block_PM')->delete( { blocker_user_id_fk => $USER->{user_id} } );

# Ok I guess there was so let's save it.
    foreach my $user (split /[\r\n]+/, $list) {
        next if $user =~ /^\s*$/; # Skip blanks.
        $user =~ s/^\s+|\s+$//g;  # Strip spaces.
        if (my $user_id = $DB->table('User')->select( { user_username => $user }, 'user_id' )->fetchrow) {
            $DB->table('Block_PM')->insert( { blocker_user_id_fk => $USER->{user_id}, blocked_user_id_fk => $user_id } );
        }
        else {
            push @errs, { error => GForum::language('BLOCK_PM_USER', $user) };
        }
    }

# Let's check what errors we have so far.
    if (@errs) {
        $GForum::Template::VARS{errors} = \@errs;
        GForum::do_func($IN->param('on_error'));
        GT::Plugins->action( STOP );
        return;
    }

    return @args;
}

# ADMIN MENU OPTIONS
# ===================================================================

sub about {
# -------------------------------------------------------------------
# About page.

    print $IN->header();
    print <<'ABOUT';

<html> 
<head> 
<meta http-equiv="Content-Type" content="text/html; charset=windows-1252"> 
<title>Gossamer Forum - Block_PM Plugin</title> 
</head> 
<body bgcolor="#FFFFFF"> 
<p><font face="Tahoma,Arial,Helvetica" size="3"><b> 
<table border="1" cellpadding="0" cellspacing="0">
<tr>
<td> 
<table bgColor="#ffffff" border="0" cellPadding="3" cellSpacing="3" width="500" valign="top"> 
<tr> 
<td align="left" bgColor="navy"><b>
<font color="#ffffff" size="2" face="Tahoma,Arial,Helvetica">Block_PM Plugin</font></b></td> 
</tr> 
<tr> 
<td> 
<p align="center">
<b><font color="#000000" size="2" face="Tahoma,Arial,Helvetica">Block_PM Plugin</font></b></p> 
<p><font size="2" face="Tahoma,Arial,Helvetica">This plugin will allow you to block private messages from specific users.</font></p> 
</td> 
</tr> 
</table> 
</td>
</tr> 
</table> 
</b></font>
</p> 
<p>
<font face="Tahoma,Arial,Helvetica" size="2">
To properly install this plugin please add the following html into the user_profile_basic.html template:<br><br>
<pre style="font-face:verdana; font-size:12px">
&lt;tr>
  &lt;td align=right valign=top>
      &lt;%body_font%>
          Block Users:&lt;br>
          &lt;small>(one user per line)&lt;/small>
      &lt;%/body_font%>
  &lt;/td>
  &lt;td>
      &lt;textarea name=block_pm class=button cols="&lt;%user_cols%>" rows="&lt;%user_rows%>" wrap=soft>&lt;%if block_pm%>&lt;%block_pm%>&lt;%endif%>&lt;/textarea>
  &lt;/td>
&lt;/tr>
</pre>
<br>
That is all there is to it!
</font>
</p>
</body>
</html>
ABOUT

}

1;