# ==================================================================
# Plugins::GForum::Block_PM - Auto Generated Install Module
#
#   Plugins::GForum::Block_PM
#   Author  : Paul Wilson
#   Version : 1.0.0
#   Updated : Sat Aug 31 20:17:36 2002
#
# ==================================================================
#

package Plugins::GForum::Block_PM;
# ==================================================================
use strict;
use vars  qw/$VERSION $DEBUG $NAME $META/;
use GT::Base;
use GT::Config;
use GT::Plugins qw/STOP CONTINUE/;
use GForum qw/$IN $DB $CFG/;

$VERSION = '1.0.0';
$DEBUG   = 0;
$NAME    = 'Block_PM';
# Inhert from base class for debug and error methods
@Plugins::GForum::Block_PM::ISA = qw(GT::Base);

$META = {
    'prog_ver' => '1.1.7',
    'description' => 'This plugin will allow forum members to block private messages from specific users.',
    'license' => 'Freeware',
    'url' => 'http://www.supportsql.com',
    'author' => 'Paul Wilson',
    'version' => '1.0.0'
};


sub pre_install {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they install
# the plugin.
#
    my $inst_msg = 'Install the private message blocker plugin!';
    my $warn     = '<br><br>If the Block_PM plugin has been installed in the past it is likely that the
                    Block_PM table will already exist. If so, please tick the box below:<br><br>
                    <input type="checkbox" name="ae" value="1"> Table Exists';
    return $inst_msg . $warn;
}

sub pre_uninstall {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they remove the
# plugin.
#
    my $uninst_msg = 'Please don\'t uninstall me, what have I ever done to you?';

    return $uninst_msg;
}

sub install {
# -------------------------------------------------------------------
# This function does the actual installation. It's first argument is
# a plugin manager which you can use to register hooks, install files,
# add menu options, etc. The second argument is a GT::Tar object which
# you can use to access any files in your plugin module.
#
# You should return an HTML formatted string that will be displayed 
# to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::GForum::Block_PM::error
#
    my ($mgr, $tar) = @_;

    $mgr->install_hooks ( 'Block_PM', [ ['do_user_profile_change', 'PRE', 'Plugins::GForum::Block_PM::save_blocks', 'FIRST'] ]);
    $mgr->install_hooks ( 'Block_PM', [ ['do_user_profile_basic', 'PRE', 'Plugins::GForum::Block_PM::load_blocks', 'LAST'] ]);
    $mgr->install_hooks ( 'Block_PM', [ ['do_message_send', 'PRE', 'Plugins::GForum::Block_PM::check_block', 'FIRST'] ]);
    $mgr->install_menu ( 'Block_PM', [ ['About', 'admin.cgi?do=plugin&plugin=Block_PM&func=about'] ] );
    
# Create the new table but only if it doesn't exist.
    unless ($IN->param('ae')) {
        my $creator = $DB->creator('Block_PM');
        $creator->cols ( 
                  blocker_user_id_fk => { 
                          pos      => 1,
                          type     => 'INT',
                          size     => 10,
                          not_null => 1
                  },
                  blocked_user_id_fk => {
                          pos      => 2,
                          type     => 'INT',
                          not_null => 1,
                          size     => 10
                  }
        );
        $creator->create or return $GT::SQL::error;

# Set up the foreign key.
        $creator->fk ( { User => { blocker_user_id_fk => 'user_id' } } );
    }

# Install a new language variable.
    my $language = GT::Config->load("$CFG->{admin_root_path}/templates/$CFG->{default_template_set}/language.txt", { create_ok => 0, inheritance => 1, local => 1, debug => $CFG->{debug_level} });    
    $language->{BLOCK_PM}      = "The user '%s' is not currently accepting private messages from you!";     
    $language->{BLOCK_PM_USER} = "The user '%s' does not exist and so cannot be blocked!";     
    $language->save();

    return "The plugin has been successfully installed!";
}

sub uninstall {
# -------------------------------------------------------------------
# This function removes the plugin. It's first argument is
# also a plugin manager which you can use to register hooks, install files,
# add menu options, etc. You should return an HTML formatted string
# that will be displayed to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::GForum::Block_PM::error
#
    my $mgr = shift;

    $mgr->uninstall_hooks ( 'Block_PM', [ ['do_user_profile_change', 'PRE', 'Plugins::GForum::Block_PM::save_blocks', 'FIRST'] ]);
    $mgr->uninstall_hooks ( 'Block_PM', [ ['do_user_profile_basic', 'PRE', 'Plugins::GForum::Block_PM::load_blocks', 'LAST'] ]);
    $mgr->uninstall_hooks ( 'Block_PM', [ ['do_message_send', 'PRE', 'Plugins::GForum::Block_PM::check_block', 'FIRST'] ]);
    $mgr->uninstall_menu ( 'Block_PM', [ ['About', 'admin.cgi?do=plugin&plugin=Block_PM&func=about'] ] );
    
    return "The plugin has been successfully removed!";
}

1;
